==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.contenttypes.contacts/test/com/openexchange/usm/contenttypes/contacts/impl/ContactsContentTypeTransferHandlerTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.contacts.impl;

import junit.framework.Test;

import com.openexchange.usm.contenttypes.contacts.impl.ContactContentTypeImpl;
import com.openexchange.usm.contenttypes.contacts.impl.ContactContentTypeTransferHandler;
import com.openexchange.usm.contenttypes.test.ContentTypeTransferHandlerTest;
import com.openexchange.usm.contenttypes.util.UtilConstants;
import com.openexchange.usm.journal.SimJournal;
import com.openexchange.usm.ox_json.SimOXJSONAcess;

public class ContactsContentTypeTransferHandlerTest extends ContentTypeTransferHandlerTest {

	static String _propsPath = "../com.openexchange.usm.contenttypes.contacts/testfiles/";

	private boolean initialized = false;

	public static Test suite() {
		return createTestSuite(_propsPath, "ContactsTestRepeater", ContactsContentTypeTransferHandlerTest.class);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		if (!initialized) {
			SimJournal _journal = new SimJournal();
			ContactContentTypeImpl contentType = new ContactContentTypeImpl();
			SimOXJSONAcess _oxAjaxAccess = new SimOXJSONAcess();
			ContactContentTypeTransferHandler _transferHandler = new ContactContentTypeTransferHandler(
					contentType, _journal.getLog(ContactContentTypeTransferHandler.class), _oxAjaxAccess);
			String _requestPath = UtilConstants.CONTACT_PATH;
			initialize(_journal, _oxAjaxAccess, _transferHandler, _propsPath, _requestPath, contentType);
			initialized = true;
		}
	}
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.contenttypes.contacts/test/com/openexchange/usm/contenttypes/contacts/impl/ContactsContentTypeTransferHandlerTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.contacts.impl;

import junit.framework.Test;

import com.openexchange.usm.contenttypes.test.ContentTypeTransferHandlerTest;
import com.openexchange.usm.contenttypes.util.UtilConstants;
import com.openexchange.usm.journal.SimJournal;
import com.openexchange.usm.ox_json.SimOXJSONAcess;

public class ContactsContentTypeTransferHandlerTest extends ContentTypeTransferHandlerTest {

	public static String _propsPath = "../com.openexchange.usm.contenttypes.contacts/testfiles/";

	private boolean _initialized = false;

	public static Test suite() {
		return createTestSuite(_propsPath, "ContactsTestRepeater", ContactsContentTypeTransferHandlerTest.class);
	}

	@Override
	protected void setUp() throws Exception {
		super.setUp();
		if (!_initialized) {
			SimJournal journal = new SimJournal();
			ContactContentTypeImpl contentType = new ContactContentTypeImpl();
			SimOXJSONAcess oxAjaxAccess = new SimOXJSONAcess();
			ContactContentTypeTransferHandler transferHandler = new ContactContentTypeTransferHandler(contentType,
					journal.getLog(ContactContentTypeTransferHandler.class), oxAjaxAccess);
			String requestPath = UtilConstants.CONTACT_PATH;
			initialize(journal, oxAjaxAccess, transferHandler, _propsPath, requestPath, contentType);
			_initialized = true;
		}
	}
}
